@@ -14,6 +14,8 @@ use Carp;
 use Params::Validate qw(:all);
 use File::Spec;
 use File::Path;
+use IO::All;
+use JSON::XS;
 
 extends "Rex::Repositorio::Repository::Base";
 
@@ -229,6 +231,7 @@ sub _run_createrepo {
   }
 }
 
+
 # test if all necessary parameters are available
 override verify_options => sub {
   my $self = shift;
